@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: dns
 version: 2.0.1
-id: dns-2.0.1-3bc6bd18964f4fcaee15d296f6088006
-key: dns_4EhFUrGxao38gqu5bEE97a
+id: dns-2.0.1-43f9ea4f8a2a4a542cc054d8867fb759
+key: dns_1jFIYXyiB7pIgTmF06vwYW
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: DNS library in Haskell
@@ -22,7 +22,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/dns-2.0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/dns-2.0.1
-hs-libraries: HSdns-2.0.1-4EhFUrGxao38gqu5bEE97a
+hs-libraries: HSdns-2.0.1-1jFIYXyiB7pIgTmF06vwYW
 depends:
     attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -30,7 +30,7 @@ depends:
     blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
+    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
